backports_zoneinfo: Backport of the standard library zoneinfo module
====================================================================

Description
-----------

Backport of the standard library zoneinfo module for Python 3.8

License
-------

Apache-2.0

Upstream Contact
----------------

https://pypi.org/project/backports.zoneinfo/

